aboutsummaryrefslogtreecommitdiff
path: root/utils
diff options
context:
space:
mode:
Diffstat (limited to 'utils')
-rwxr-xr-xutils/updater-ng-auto.sh (renamed from utils/opkg-trans-master.sh)8
1 files changed, 5 insertions, 3 deletions
diff --git a/utils/opkg-trans-master.sh b/utils/updater-ng-auto.sh
index b16845c..449b045 100755
--- a/utils/opkg-trans-master.sh
+++ b/utils/updater-ng-auto.sh
@@ -5,8 +5,8 @@
UPDATER_REPO=https://kkoci@gitlab.labs.nic.cz/turris/updater.git
UPDATER_REPO_PATH=/tmp/myrepo_updater_repo
-if [ ! -f $1/opkg-trans-master-auto/Makefile ]; then
- # Skip this when we don't have opkg-trans-master-auto
+if [ ! -f $1/updater-ng-auto/Makefile ]; then
+ # Skip this when we don't have updater-ng-auto
exit
fi
@@ -23,4 +23,6 @@ VERSION="$(git $GIT_ARGS describe --abbrev=0 --tags)"
RELEASE="$(($(git $GIT_ARGS rev-list --count $VERSION..HEAD) + 1))"
# Now replace stuff in Makefile
-sed -i "s/^PKG_VERSION:=.*/PKG_VERSION:=$VERSION/;s/^PKG_RELEASE:=.*/PKG_RELEASE:=$RELEASE/;s/^PKG_SOURCE_VERSION:=.*/PKG_SOURCE_VERSION:=$HASH/" $1/opkg-trans-master-auto/Makefile
+sed -i "s/^PKG_VERSION:=.*/PKG_VERSION:=$VERSION/;s/^PKG_RELEASE:=.*/PKG_RELEASE:=$RELEASE/;s/^PKG_SOURCE_VERSION:=.*/PKG_SOURCE_VERSION:=$HASH/" $1/updater-ng-auto/Makefile
+
+echo -e "\e[1;35mUpdater-ng package has now version: $VERSION-$RELEASE\e[0m"